Functions
- git_dir
- Get the .git directory of the current repository.
- initial_
commit_ sha - Get the initial commit SHA of the repository (project identifier).
- is_
in_ repo - Check if we’re inside a git repository.
- last_
commit_ message - Get the last commit message from the main repository.
- repo_
root - Get the root directory of the current git repository.
- run
- Run a git command and return stdout on success.
- run_
with_ paths - Run a git command with a specific work-tree and git-dir.