last_commit_message

Function last_commit_message 

pub fn last_commit_message() -> Result<String>
Get the last commit message from the main repository.

Errors

Returns an error if the git log command fails.