run

Function run 

pub fn run(args: &[&str]) -> Result<String>
Run a git command and return stdout on success.

Errors

Returns an error if the git command fails to execute or exits with non-zero status.