Module git

Module git 

Functions

git_dir
Get the .git directory of the current repository.
initial_commit_sha
Get the initial commit SHA of the repository (project identifier).
is_in_repo
Check if we’re inside a git repository.
last_commit_message
Get the last commit message from the main repository.
repo_root
Get the root directory of the current git repository.
run
Run a git command and return stdout on success.
run_with_paths
Run a git command with a specific work-tree and git-dir.